<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="80px"
    >
      <el-row :gutter="24">
        <el-col :span="12">
          <el-form-item label="数据类型" prop="dataType">
            <el-input v-model="formData.dataType" placeholder=""/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="数据名称" prop="dataName">
            <el-input v-model="formData.dataName" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="数据编号" prop="dataNo">
            <el-input v-model="formData.dataNo" placeholder=""/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="左侧长度" prop="leftLength">
            <el-input v-model="formData.leftLength" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="右侧长度" prop="rightLength">
            <el-input v-model="formData.rightLength" placeholder=""/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="排序" prop="sort">
            <el-input v-model="formData.sort" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="拓展字段1" prop="ext1">
            <el-input v-model="formData.ext1" placeholder=""/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="拓展字段2" prop="ext2">
            <el-input v-model="formData.ext2" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="拓展字段3" prop="ext3">
            <el-input v-model="formData.ext3" placeholder=""/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="拓展字段4" prop="ext4">
            <el-input v-model="formData.ext4" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row :gutter="20">
        <el-col :span="12">
          <el-form-item label="拓展字段5" prop="ext5">
            <el-input v-model="formData.ext5" placeholder=""/>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
  import * as ConfigDetApi from '@/api/model/sche/suggest/snapshotConfigDet'
import {deleteIcon} from "@/api/model/mpk/icon";

defineOptions({ name: 'ConfigDetForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  confId: undefined,
  dataType: undefined,
  dataName: undefined,
  dataNo: undefined,
  leftLength: undefined,
  rightLength: undefined,
  sort: undefined,
  ext1: undefined,
  ext2: undefined,
  ext3: undefined,
  ext4: undefined,
  ext5: undefined,
})
const formRules = reactive({
  dataType: [{ required: true, message: '不能为空', trigger: 'blur' }],
  dataName: [{ required: true, message: '不能为空', trigger: 'blur' }],
  dataNo: [{ required: true, message: '不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

  /** 打开弹窗 */
  const open = async (type: string, id?: string, confId?: string) => {
    dialogVisible.value = true
    dialogTitle.value = t('action.' + type)
    formType.value = type
    resetForm()
    formData.confId = confId
    // 修改时，设置数据
    if (id) {
      formLoading.value = true
      try {
        formData.value = await ConfigDetApi.get(id)
      } finally {
        formLoading.value = false
      }
    }
  }
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value
    if (formType.value === 'create') {
      await ConfigDetApi.create(data)
      message.success(t('common.createSuccess'))
    } else {
      await ConfigDetApi.update(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    confId: undefined,
    dataType: undefined,
    dataNo: undefined,
    leftLength: undefined,
    rightLength: undefined,
    sort: undefined,
    ext1: undefined,
    ext2: undefined,
    ext3: undefined,
    ext4: undefined,
    ext5: undefined,
  }
  formRef.value?.resetFields()
}
</script>
